==> foundation-2.6.1.tgz: package/Elevator/Elevator.esm.js <==
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export const Elevator = /*#__PURE__*/React.forwardRef((props, ref) => {
  const attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, Object.assign({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", null, /*#__PURE__*/React.createElement("path", {
    d: "M77.741 10.79H4.36a2.521 2.521 0 00-2.519 2.521V86.69a2.522 2.522 0 002.519 2.521h73.381a2.52 2.52 0 002.521-2.521V13.311a2.52 2.52 0 00-2.521-2.521zM11.862 20.809h58.381V79.19H11.862V20.809zm85.662 43.157h-2.882v-7.737a.595.595 0 00-.595-.596h-5.333a.595.595 0 00-.595.596v7.736h-2.883a.598.598 0 00-.484.942l6.164 8.616a.593.593 0 00.483.248h.001a.594.594 0 00.484-.25l6.125-8.615a.595.595 0 00-.485-.94zM85.276 36.035h2.882v7.737c0 .329.267.595.596.596l5.333-.001a.594.594 0 00.595-.595v-7.737h2.883a.595.595 0 00.484-.941l-6.164-8.615a.594.594 0 00-.483-.25h-.001a.6.6 0 00-.485.252l-6.124 8.614a.596.596 0 00.484.94z"
  }), /*#__PURE__*/React.createElement("circle", {
    cx: 27.998,
    cy: 31.993,
    r: 4.955
  }), /*#__PURE__*/React.createElement("path", {
    d: "M37.38 38.28v-.024H19.628v.017a2.332 2.332 0 00-2.332 2.316h-.002v14.04h.023a2.083 2.083 0 104.166 0h.005v-9.802h.006a.662.662 0 01.66-.638c.358 0 .646.283.661.638h.006v25.701a2.436 2.436 0 004.874-.003V57.584h.018a.675.675 0 111.35 0h.017v12.941a2.438 2.438 0 004.874 0V44.828a.666.666 0 111.331 0v9.802h.023a2.083 2.083 0 104.167 0h.004V40.59a2.33 2.33 0 00-2.099-2.31z"
  }), /*#__PURE__*/React.createElement("circle", {
    cx: 53.331,
    cy: 31.993,
    r: 4.955
  }), /*#__PURE__*/React.createElement("path", {
    d: "M62.713 38.28v-.024H44.961v.017a2.332 2.332 0 00-2.332 2.316h-.002v14.04h.023a2.083 2.083 0 104.166 0h.005v-9.802h.006a.662.662 0 01.66-.638c.358 0 .646.283.661.638h.006v25.701a2.436 2.436 0 004.874-.003V57.584h.018a.675.675 0 111.35 0h.017v12.941a2.438 2.438 0 004.874 0V44.828a.666.666 0 111.331 0v9.802h.023a2.083 2.083 0 104.167 0h.004V40.59a2.331 2.331 0 00-2.099-2.31z"
  })));
});
Elevator.displayName = 'Elevator';
export const ElevatorDimensions = {
  height: 100,
  width: 100
};

==> foundation-2.7.1.tgz: package/Elevator/Elevator.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Elevator = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("g", null, /*#__PURE__*/React.createElement("path", {
    d: "M77.741 10.79H4.36a2.521 2.521 0 00-2.519 2.521V86.69a2.522 2.522 0 002.519 2.521h73.381a2.52 2.52 0 002.521-2.521V13.311a2.52 2.52 0 00-2.521-2.521zM11.862 20.809h58.381V79.19H11.862V20.809zm85.662 43.157h-2.882v-7.737a.595.595 0 00-.595-.596h-5.333a.595.595 0 00-.595.596v7.736h-2.883a.598.598 0 00-.484.942l6.164 8.616a.593.593 0 00.483.248h.001a.594.594 0 00.484-.25l6.125-8.615a.595.595 0 00-.485-.94zM85.276 36.035h2.882v7.737c0 .329.267.595.596.596l5.333-.001a.594.594 0 00.595-.595v-7.737h2.883a.595.595 0 00.484-.941l-6.164-8.615a.594.594 0 00-.483-.25h-.001a.6.6 0 00-.485.252l-6.124 8.614a.596.596 0 00.484.94z"
  }), /*#__PURE__*/React.createElement("circle", {
    cx: 27.998,
    cy: 31.993,
    r: 4.955
  }), /*#__PURE__*/React.createElement("path", {
    d: "M37.38 38.28v-.024H19.628v.017a2.332 2.332 0 00-2.332 2.316h-.002v14.04h.023a2.083 2.083 0 104.166 0h.005v-9.802h.006a.662.662 0 01.66-.638c.358 0 .646.283.661.638h.006v25.701a2.436 2.436 0 004.874-.003V57.584h.018a.675.675 0 111.35 0h.017v12.941a2.438 2.438 0 004.874 0V44.828a.666.666 0 111.331 0v9.802h.023a2.083 2.083 0 104.167 0h.004V40.59a2.33 2.33 0 00-2.099-2.31z"
  }), /*#__PURE__*/React.createElement("circle", {
    cx: 53.331,
    cy: 31.993,
    r: 4.955
  }), /*#__PURE__*/React.createElement("path", {
    d: "M62.713 38.28v-.024H44.961v.017a2.332 2.332 0 00-2.332 2.316h-.002v14.04h.023a2.083 2.083 0 104.166 0h.005v-9.802h.006a.662.662 0 01.66-.638c.358 0 .646.283.661.638h.006v25.701a2.436 2.436 0 004.874-.003V57.584h.018a.675.675 0 111.35 0h.017v12.941a2.438 2.438 0 004.874 0V44.828a.666.666 0 111.331 0v9.802h.023a2.083 2.083 0 104.167 0h.004V40.59a2.331 2.331 0 00-2.099-2.31z"
  })));
});
Elevator.displayName = 'Elevator';
export var ElevatorDimensions = {
  height: 100,
  width: 100
};
